@@ -69,7 +69,7 @@ class PartMan(QtGui.QWidget):
                     controller=self.ctrlr)
                 self.part_advanced_bar_frame.layout().addWidget(partition_bar)
 
-                #hide all the other bars at first
+                # hide all the other bars at first
                 if self.active_bar:
                     partition_bar.setVisible(False)
                 else:
@@ -149,8 +149,7 @@ class PartMan(QtGui.QWidget):
             dialog.partition_create_use_combo.currentIndexChanged[int].connect(
                 self.on_partition_create_use_combo_changed)
 
-            # TODO
-            #self.translate_widget_children(dialog)
+            self.ctrlr._wizard.translate_widget_children(dialog)
 
         # TODO cjwatson 2006-11-01: Because partman doesn't use a question
         # group for these, we have to figure out in advance whether each
@@ -194,8 +193,8 @@ class PartMan(QtGui.QWidget):
         dialog.partition_create_mount_combo.clear()
         for mp, choice_c, choice in (
                 self.ctrlr.dbfilter.default_mountpoint_choices()):
-            ##FIXME gtk frontend has a nifty way of showing the user readable
-            ##'choice' text in the drop down, but only selecting the 'mp' text
+            # FIXME gtk frontend has a nifty way of showing the user readable
+            # 'choice' text in the drop down, but only selecting the 'mp' text
             dialog.partition_create_mount_combo.addItem(mp)
         dialog.partition_create_mount_combo.clearEditText()
 
@@ -252,7 +251,7 @@ class PartMan(QtGui.QWidget):
         if not self.ctrlr.allowed_change_step():
             return
 
-        #lazy loading
+        # lazy loading
         dialog = self.edit_dialog
         if not dialog:
             self.edit_dialog = QtGui.QDialog(self)
@@ -261,8 +260,7 @@ class PartMan(QtGui.QWidget):
             dialog.partition_edit_use_combo.currentIndexChanged[int].connect(
                 self.on_partition_edit_use_combo_changed)
 
-            # TODO
-            #self.translate_widget_children(dialog)
+            self.ctrlr._wizard.translate_widget_children(dialog)
 
         current_size = None
         if ('can_resize' not in partition or not partition['can_resize'] or
@@ -420,7 +418,7 @@ class PartMan(QtGui.QWidget):
             if 'can_new' in partition and partition['can_new']:
                 self.partman_create_dialog(devpart, partition)
 
-    ### actions for clicking the buttons ###
+    # actions for clicking the buttons
 
     def get_treeview_data(self):
         selected = self.partition_list_treeview.selectedIndexes()
