@@ -19,15 +19,15 @@
 
 from __future__ import print_function
 
+import codecs
+from functools import reduce
+import locale
+import os
 import re
 import subprocess
-import codecs
-import os
-import locale
 import sys
-from functools import reduce
 
-from ubiquity import misc, im_switch
+from ubiquity import im_switch, misc
 
 
 def reset_locale(frontend):
@@ -213,6 +213,8 @@ def map_widget_name(prefix, name):
     elif name in string_questions:
         question = string_questions[name]
     else:
+        if name.endswith('1'):
+            name = name[:-1]
         question = '%s/%s' % (prefix, name)
     return question
 
@@ -272,9 +274,9 @@ def get_languages(current_language_index=-1, only_installable=False):
 
     if only_installable:
         from apt.cache import Cache
-        #workaround for an issue where euid != uid and the
-        #apt cache has not yet been loaded causing a SystemError
-        #when libapt-pkg tries to load the Cache the first time.
+        # workaround for an issue where euid != uid and the
+        # apt cache has not yet been loaded causing a SystemError
+        # when libapt-pkg tries to load the Cache the first time.
         with misc.raised_privileges():
             cache = Cache()
 
@@ -294,12 +296,12 @@ def get_languages(current_language_index=-1, only_installable=False):
         # NO-BREAK SPACE, and we don't care about the NBSP anyway, so strip
         # it.
         #   https://bugs.launchpad.net/bugs/1001542
-        #   (comment #5 and on)
+        #   (comment # 5 and on)
         trans = trans.strip(" \ufeff")
 
         if only_installable:
             pkg_name = 'language-pack-%s' % code
-            #special case these
+            # special case these
             if pkg_name.endswith('_CN'):
                 pkg_name = 'language-pack-zh-hans'
             elif pkg_name.endswith('_TW'):
