@@ -475,6 +475,24 @@ def archdetect():
         return answer, ''
 
 
+def is_secure_boot():
+    try:
+        secureboot = ''
+        secureboot_efivar = subprocess.Popen(
+            ['od', '-An', '-t', 'u1',
+             os.path.join('/sys/firmware/efi/efivars',
+                          'SecureBoot-8be4df61-93ca-11d2-aa0d-00e098032b8c')],
+            stdout=subprocess.PIPE, universal_newlines=True)
+        answer = secureboot_efivar.communicate()[0].strip()
+        if answer is not None:
+            secureboot = answer.split(' ')[-1]
+        if len(secureboot) > 0:
+            return (int(secureboot) == 1)
+        return False
+    except:
+        return False
+
+
 # TODO this can probably go away now.
 def get_cache_pkg(cache, pkg):
     # work around broken has_key in python-apt 0.6.16
