@@ -374,10 +374,7 @@ def grub_default(boot=None):
             else:
                 # Try the next disk along (which can't also be the CD source).
                 target = os.path.realpath(devices[1].split('\t')[1])
-            target = re.sub(r'(/dev/(cciss|ida)/c[0-9]d[0-9]|\
-                            /dev/nvme[0-9]+n[0-9]+|\
-                            /dev/[a-z]+\
-                            ).*',
+            target = re.sub(r'(/dev/(cciss|ida)/c[0-9]d[0-9]|/dev/[a-z]+).*',
                             r'\1', target)
         except (IndexError, OSError):
             pass
@@ -603,15 +600,6 @@ def create_bool(text):
         return text
 
 
-# On hardware that uses SMBIOS 2.8+, dmidecode 2.12 will contain this warning
-# message prefixed before system-version, system-product-name, etc.  This is
-# problematic as the default hostname built by Ubiquity wont be valid (it's too
-# long), so we strip this prefix.  Note there is no reason to forward-port this
-# to Xenial as it uses dmidecode 3.0, which doesn't have this problem.
-SMBIOS28_JUNK = 'SMBIOS-implementations-newer-than-version-2-8-are-not-fully-\
-supported-by-this-version-of-dmidecode-'
-
-
 @raise_privileges
 def dmimodel():
     model = ''
@@ -621,7 +609,7 @@ def dmimodel():
         kwargs['stderr'] = open('/dev/null', 'w')
     try:
         proc = subprocess.Popen(
-            ['dmidecode', '--string', 'system-manufacturer'],
+            ['dmidecode', '--quiet', '--string', 'system-manufacturer'],
             stdout=subprocess.PIPE, universal_newlines=True, **kwargs)
         manufacturer = proc.communicate()[0]
         if not manufacturer:
@@ -638,9 +626,10 @@ def dmimodel():
                 key = 'system-version'
             else:
                 key = 'system-product-name'
-            proc = subprocess.Popen(['dmidecode', '--string', key],
-                                    stdout=subprocess.PIPE,
-                                    universal_newlines=True)
+            proc = subprocess.Popen(
+                ['dmidecode', '--quiet', '--string', key],
+                stdout=subprocess.PIPE,
+                universal_newlines=True)
             model = proc.communicate()[0]
         if 'apple' in manufacturer:
             # MacBook4,1 - strip the 4,1
@@ -650,8 +639,8 @@ def dmimodel():
         model = re.sub('[^a-zA-Z0-9]+', '-', model).rstrip('-').lstrip('-')
         if model.lower() == 'not-available':
             return
-        if model.startswith(SMBIOS28_JUNK):
-            model = model[len(SMBIOS28_JUNK):]
+        if model.lower() == "To be filled by O.E.M.".lower():
+            return
     except Exception:
         syslog.syslog(syslog.LOG_ERR, 'Unable to determine the model from DMI')
     finally:
